/*
  defaults.h - defaults settings configuration file
  Part of Grbl v0.9

  Copyright (c) 2012-2014 Sungeun K. Jeon

  Grbl is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Grbl is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Grbl.  If not, see <http://www.gnu.org/licenses/>.
*/

/* The defaults.h file serves as a central default settings file for different machine
   types, from DIY CNC mills to CNC conversions of off-the-shelf machines. The settings
   here are supplied by users, so your results may vary. However, this should give you
   a good starting point as you get to know your machine and tweak the settings for your
   our nefarious needs. */

#ifndef defaults_h
#define defaults_h

#ifdef DEFAULTS_3020Z
  // Grbl generic default settings. Should work across different machines.
  #define DEFAULT_X_STEPS_PER_MM 640.0
  #define DEFAULT_Y_STEPS_PER_MM 640.0
  #define DEFAULT_Z_STEPS_PER_MM 640.0
  #define DEFAULT_X_MAX_RATE 3000.0 // mm/min
  #define DEFAULT_Y_MAX_RATE 3000.0 // mm/min
  #define DEFAULT_Z_MAX_RATE 3000.0 // mm/min
  #define DEFAULT_X_ACCELERATION (100.0*60*60) // 10*60*60 mm/min^2 = 10 mm/sec^2
  #define DEFAULT_Y_ACCELERATION (100.0*60*60) // 10*60*60 mm/min^2 = 10 mm/sec^2
  #define DEFAULT_Z_ACCELERATION (100.0*60*60) // 10*60*60 mm/min^2 = 10 mm/sec^2
  #define DEFAULT_X_MAX_TRAVEL 250.0 // mm
  #define DEFAULT_Y_MAX_TRAVEL 150.0 // mm
  #define DEFAULT_Z_MAX_TRAVEL 50.0 // mm
  #define DEFAULT_STEP_PULSE_MICROSECONDS 10
  #define DEFAULT_STEPPING_INVERT_MASK 0
  #define DEFAULT_DIRECTION_INVERT_MASK ((1<<Z_AXIS))
  #define DEFAULT_STEPPER_IDLE_LOCK_TIME 25 // msec (0-254, 255 keeps steppers enabled)
  #define DEFAULT_STATUS_REPORT_MASK ((BITFLAG_RT_STATUS_MACHINE_POSITION)|(BITFLAG_RT_STATUS_WORK_POSITION))
  #define DEFAULT_JUNCTION_DEVIATION 0.02 // mm
  #define DEFAULT_ARC_TOLERANCE 0.002 // mm
  #define DEFAULT_REPORT_INCHES 0 // false
  #define DEFAULT_AUTO_START 1 // true
  #define DEFAULT_INVERT_ST_ENABLE 0 // false
  #define DEFAULT_INVERT_LIMIT_PINS 0 // false
  #define DEFAULT_SOFT_LIMIT_ENABLE 0 // true
  #define DEFAULT_HARD_LIMIT_ENABLE 1 // true
  #define DEFAULT_HOMING_ENABLE 1  // true
  #define DEFAULT_HOMING_DIR_MASK ((1<<X_AXIS) | (1<<Y_AXIS)) // X-Y neg-dir
  #define DEFAULT_HOMING_FEED_RATE 25.0 // mm/min
  #define DEFAULT_HOMING_SEEK_RATE 500.0 // mm/min
  #define DEFAULT_HOMING_DEBOUNCE_DELAY 250 // msec (0-65k)
  #define DEFAULT_HOMING_PULLOFF 1.0 // mm
#endif
/*
 Unhandeled response: "$0=10 (step pulse, usec)" 
 
Unhandeled response: "$1=25 (step idle delay, msec)" 
 
Unhandeled response: "$2=0 (step port invert mask:00000000)" 
 
Unhandeled response: "$3=4 (dir port invert mask:00000100)" 
 
Unhandeled response: "$4=0 (step enable invert, bool)" 
 
Unhandeled response: "$5=0 (limit pins invert, bool)" 
 
Unhandeled response: "$6=0 (probe pin invert, bool)" 
 
Unhandeled response: "$10=3 (status report mask:00000011)" 
 
Unhandeled response: "$11=0.020 (junction deviation, mm)" 
 
Unhandeled response: "$12=0.002 (arc tolerance, mm)" 
 
Unhandeled response: "$13=0 (report inches, bool)" 
 
Unhandeled response: "$14=1 (auto start, bool)" 
 
Unhandeled response: "$20=0 (soft limits, bool)" 
 
Unhandeled response: "$21=1 (hard limits, bool)" 
 
Unhandeled response: "$22=1 (homing cycle, bool)" 
 
Unhandeled response: "$23=3 (homing dir invert mask:00000011)" 
 
Unhandeled response: "$24=25.000 (homing feed, mm/min)" 
 
Unhandeled response: "$25=500.000 (homing seek, mm/min)" 
 
Unhandeled response: "$26=250 (homing debounce, msec)" 
 
Unhandeled response: "$27=1.000 (homing pull-off, mm)" 
 
Unhandeled response: "$100=640.000 (x, step/mm)" 
 
Unhandeled response: "$101=640.000 (y, step/mm)" 
 
Unhandeled response: "$102=640.000 (z, step/mm)" 
 
Unhandeled response: "$110=3000.000 (x max rate, mm/min)" 
 
Unhandeled response: "$111=3000.000 (y max rate, mm/min)" 
 
Unhandeled response: "$112=3000.000 (z max rate, mm/min)" 
 
Unhandeled response: "$120=100.000 (x accel, mm/sec^2)" 
 
Unhandeled response: "$121=100.000 (y accel, mm/sec^2)" 
 
Unhandeled response: "$122=100.000 (z accel, mm/sec^2)" 
 
Unhandeled response: "$130=250.000 (x max travel, mm)" 
 
Unhandeled response: "$131=150.000 (y max travel, mm)" 
 
Unhandeled response: "$132=50.000 (z max travel, mm)" 
 
Reported Error: "Not idle" 
 
*/
#endif